import { CacheFactoryRegistry } from '../Registry/CacheFactoryRegistry.js';
/**
 * Factory class for creating cache instances based on configuration.
 * Uses the CacheFactoryRegistry to instantiate the appropriate cache implementation.
 */
export class CacheFactoryFactory {
    /**
     * Creates a cache instance based on the provided configuration.
     *
     * @param {TypeCacheConfig} config - The configuration object for the cache provider
     * @returns {CacheInterface} A cache provider instance
     * @throws {Error} When the requested cache provider cannot be created
     */
    createCache(config) {
        const factoryConstructor = CacheFactoryRegistry.getCacheFactory(config.CACHE_TYPE ?? 'unknown');
        const factory = new factoryConstructor();
        return factory.createCache(config);
    }
}
