import type { TypeCacheConfig } from '../Type/index.js';
import type { CacheInterface } from './CacheInterface.js';
/**
 * Interface representing a cache factory.
 * Implementations should handle the creation of specific cache providers.
 *
 * @template TypeConfig The configuration type for this cache factory, must extend TypeCacheConfig
 */
export interface CacheFactoryInterface<TypeConfig extends TypeCacheConfig = TypeCacheConfig> {
    /**
     * Creates a cache instance based on the provided configuration.
     *
     * @param {TypeConfig} config - The configuration object for the cache provider
     * @returns {CacheInterface} A cache provider instance
     * @throws {Error} When the requested cache provider cannot be created
     */
    createCache(config: TypeConfig): CacheInterface;
}
