import type { CacheFactoryConstructor } from '../Type/index.js';
import type { CacheFactoryInterface } from '../Interface/index.js';
import type { TypeCacheConfig } from '../Type/index.js';
export declare class CacheFactoryRegistry {
    private static cacheFactories;
    /**
     * Register cache factory for a type.
     *
     * @param {string} type - The unique identifier for the cache factory
     * @param {CacheFactoryConstructor} cacheFactory - The cache factory constructor
     * @returns {void}
     */
    static registerCacheFactory(type: string, cacheFactory: CacheFactoryConstructor<CacheFactoryInterface<TypeCacheConfig>, TypeCacheConfig>): void;
    /**
     * Get a cache factory by type.
     *
     * @param {string} type - The type identifier of the cache factory
     * @returns {CacheFactoryConstructor} The cache factory constructor
     * @throws {Error} If no factory is found for the given type
     */
    static getCacheFactory(type: string): CacheFactoryConstructor<CacheFactoryInterface<TypeCacheConfig>, TypeCacheConfig>;
}
