export class CacheFactoryRegistry {
    static cacheFactories = {};
    /**
     * Register cache factory for a type.
     *
     * @param {string} type - The unique identifier for the cache factory
     * @param {CacheFactoryConstructor} cacheFactory - The cache factory constructor
     * @returns {void}
     */
    static registerCacheFactory(type, cacheFactory) {
        this.cacheFactories[type] = cacheFactory;
    }
    /**
     * Get a cache factory by type.
     *
     * @param {string} type - The type identifier of the cache factory
     * @returns {CacheFactoryConstructor} The cache factory constructor
     * @throws {Error} If no factory is found for the given type
     */
    static getCacheFactory(type) {
        const factoryClass = this.cacheFactories[type];
        if (!factoryClass) {
            throw new Error(`No cache factory found for the type "${type}".`);
        }
        return factoryClass;
    }
}
