/**
 * Base configuration interface for all cache providers.
 * Each provider should extend this interface with their specific configuration requirements.
 *
 * @example
 * ```typescript
 * interface TypeRedisCacheConfig extends TypeCacheConfig {
 *   CACHE_REDIS_URL: string;
 *   CACHE_REDIS_PORT: number;
 * }
 * ```
 */
export interface TypeCacheConfig {
    /**
     * Identifier for the cache provider type.
     * This is used to look up the appropriate factory in the registry.
     *
     * @example 'memory-cache', 'redis-cache', 'cloudflare-cache'
     */
    CACHE_TYPE: string;
}
